Title: [279964] trunk/Source/WebCore
Revision
279964
Author
[email protected]
Date
2021-07-15 14:08:46 -0700 (Thu, 15 Jul 2021)

Log Message

Reddit PiP video pauses when scrolling
https://bugs.webkit.org/show_bug.cgi?id=227999

Reviewed by Jer Noble.

Enable the `requiresUserGestureToPauseInPictureInPicture` quirk for reddit.com.

* page/Quirks.cpp:
(WebCore::Quirks::requiresUserGestureToPauseInPictureInPicture const):

Modified Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (279963 => 279964)


--- trunk/Source/WebCore/ChangeLog	2021-07-15 21:04:58 UTC (rev 279963)
+++ trunk/Source/WebCore/ChangeLog	2021-07-15 21:08:46 UTC (rev 279964)
@@ -1,3 +1,15 @@
+2021-07-15  Peng Liu  <[email protected]>
+
+        Reddit PiP video pauses when scrolling
+        https://bugs.webkit.org/show_bug.cgi?id=227999
+
+        Reviewed by Jer Noble.
+
+        Enable the `requiresUserGestureToPauseInPictureInPicture` quirk for reddit.com.
+
+        * page/Quirks.cpp:
+        (WebCore::Quirks::requiresUserGestureToPauseInPictureInPicture const):
+
 2021-07-15  Megan Gardner  <[email protected]>
 
         Rename scrollRectIntoView to scrollContainingScrollViewsToRevealRect for clarity.

Modified: trunk/Source/WebCore/page/Quirks.cpp (279963 => 279964)


--- trunk/Source/WebCore/page/Quirks.cpp	2021-07-15 21:04:58 UTC (rev 279963)
+++ trunk/Source/WebCore/page/Quirks.cpp	2021-07-15 21:08:46 UTC (rev 279964)
@@ -1338,15 +1338,15 @@
 bool Quirks::requiresUserGestureToPauseInPictureInPicture() const
 {
 #if ENABLE(VIDEO_PRESENTATION_MODE)
     // Facebook and Twitter will naively pause a <video> element that has scrolled out of the viewport,
     // regardless of whether that element is currently in PiP mode.
-    // We should remove the quirk once <rdar://problem/67273166> and <rdar://problem/73369869> have been fixed.
+    // We should remove the quirk once <rdar://problem/67273166>, <rdar://problem/73369869>, and <rdar://problem/80645747> have been fixed.
     if (!needsQuirks())
         return false;
 
     if (!m_requiresUserGestureToPauseInPictureInPicture) {
         auto domain = RegistrableDomain(m_document->topDocument().url()).string();
-        m_requiresUserGestureToPauseInPictureInPicture = domain == "facebook.com"_s || domain == "twitter.com"_s;
+        m_requiresUserGestureToPauseInPictureInPicture = domain == "facebook.com"_s || domain == "twitter.com"_s || domain == "reddit.com"_s;
     }
 
     return *m_requiresUserGestureToPauseInPictureInPicture;
@@ -1338,15 +1338,15 @@
 {
 #if ENABLE(VIDEO_PRESENTATION_MODE)
-    // Facebook and Twitter will naively pause a <video> element that has scrolled out of the viewport,
+    // Facebook, Twitter, and Reddit will naively pause a <video> element that has scrolled out of the viewport,
     // regardless of whether that element is currently in PiP mode.
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to